from logging import getLogger

from .util import extract_text_file_from_container, add_text_file_to_container


LOGGER = getLogger(__name__)


def apply_super_resolution(client, input_volume, postprocessing_volume):
    LOGGER.info('Pre-processing the input images using super-resolution')
    volumes = {
        input_volume.name: {
            'bind': '/input',
            'mode': 'rw',
        },
        postprocessing_volume.name: {
            'bind': '/output',
            'mode': 'rw',
        },
    }
    command = [
        'th', '/root/waifu2x/waifu2x.lua', '-force_cudnn', '1', '-resume', '1',
        '-model_dir', '/root/waifu2x/models/anime_style_art_rgb', '-m', 'noise_scale',
        '-scale', '2', '-noise_level', '3', '-l', '/input/list.txt',
    ]
    with create_temporary_docker_container(client, 'ahisto/waifu2x', gpu=True. command=command,
            volumes=volumes, working_dir='/output') as container:
        filenames = [
            '{}_noise_scale.png'.format(Path(filename).with_suffix(''))
            for filename
            in extract_text_file_from_container(container, '/input/list.txt').split('\n')
        ]
        add_text_file_to_container(container, '/output/list.txt', '\n'.join(filenames))
        container.start()
        container.wait()
